==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/he/mail.php <==
<?php

return array(
    'a_user_canceled' => 'משתמש ביטל בקשת פריט באתר',
    'a_user_requested' => 'משתמש ביקש פריט באתר',
    'accessory_name' => 'שם אביזר:',
    'additional_notes' => 'הערות נוספות:',
    'admin_has_created' => 'מנהל מערכת יצר עבורך חשבון באתר האינטרנט:.',
    'asset' => 'נכס:',
    'asset_name' => 'שם הנכס:',
    'asset_requested' => 'הנכס המבוקש',
    'asset_tag' => 'תג נכס:',
    'assigned_to' => 'שהוקצה ל',
    'best_regards' => 'כל טוב,',
    'canceled' => 'בּוּטלָה:',
    'checkin_date' => 'תאריך הגעה:',
    'checkout_date' => 'תבדוק את התאריך:',
    'click_to_confirm' => 'לחץ על הקישור הבא כדי לאשר את: חשבון האינטרנט שלך:',
    'click_on_the_link_accessory' => 'לחץ על הקישור בתחתית הדף כדי לאשר שקיבלת את האביזר.',
    'click_on_the_link_asset' => 'לחץ על הקישור שבתחתית כדי לאשר שקיבלת את הנכס.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY הנוכחי',
    'Days' => 'ימים',
    'days' => 'ימים',
    'expecting_checkin_date' => 'תאריך הצפוי:',
    'expires' => 'יפוג',
    'Expiring_Assets_Report' => 'דוח נכסים שפג תוקפם.',
    'Expiring_Licenses_Report' => 'דוח רישיונות שפג תוקפם.',
    'hello' => 'שלום',
    'hi' => 'היי',
    'i_have_read' => 'קראתי והסכמתי לתנאי השימוש וקיבלתי פריט זה.',
    'item' => 'פריט:',
    'Item_Request_Canceled' => 'פריט בקשה בוטלה',
    'Item_Requested' => 'פריט מבוקש',
    'link_to_update_password' => 'לחץ על הקישור הבא כדי לעדכן את: סיסמת האינטרנט:',
    'login_first_admin' => 'היכנס למערכת ההתקנה החדשה של Snipe-IT באמצעות פרטי הכניסה הבאים:',
    'login' => 'התחברות:',
    'Low_Inventory_Report' => 'דו"ח מלאי נמוך',
    'min_QTY' => 'מינימום QTY',
    'name' => 'שֵׁם',
    'new_item_checked' => 'פריט חדש נבדק תחת שמך, הפרטים להלן.',
    'password' => 'סיסמה:',
    'password_reset' => 'איפוס סיסמא',

    'read_the_terms' => 'אנא קרא את תנאי השימוש שלהלן.',
    'read_the_terms_and_click' => 'קרא את תנאי השימוש שלהלן ולחץ על הקישור בתחתית הדף כדי לאשר שאתה קורא את תנאי השימוש ומסכים להם, וקיבלת את הנכס.',
    'requested' => 'התקבלה:',
    'reset_link' => 'איפוס הסיסמה שלך קישור',
    'reset_password' => 'לחץ כאן כדי לאפס את הסיסמה שלך:',
    'serial' => 'מספר סידורי',
    'supplier' => 'ספק',
    'tag' => 'תָג',
    'test_email' => 'מבחן דוא"ל מאת Snipe-IT',
    'test_mail_text' => 'זהו מבחן מן Snipe- IT ניהול מערכת. אם יש לך את זה, הדואר עובד :)',
    'the_following_item' => 'הפריט הבא נבדק:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'כדי לאפס את: סיסמת האינטרנט, מלא טופס זה:',
    'type' => 'סוּג',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'משתמש',
    'username' => 'שם משתמש',
    'welcome' => 'ברוכים הבאים: שם',
    'welcome_to' => 'ברוכים הבאים ל: אינטרנט!',
    'your_credentials' => 'שלך Snipe- IT אישורים',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/he/mail.php <==
<?php

return [
    'a_user_canceled' => 'משתמש ביטל בקשת פריט באתר',
    'a_user_requested' => 'משתמש ביקש פריט באתר',
    'accessory_name' => 'שם אביזר:',
    'additional_notes' => 'הערות נוספות:',
    'admin_has_created' => 'מנהל מערכת יצר עבורך חשבון באתר האינטרנט:.',
    'asset' => 'נכס:',
    'asset_name' => 'שם הנכס:',
    'asset_requested' => 'הנכס המבוקש',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'שהוקצה ל',
    'best_regards' => 'כל טוב,',
    'canceled' => 'בּוּטלָה:',
    'checkin_date' => 'תאריך הגעה:',
    'checkout_date' => 'תבדוק את התאריך:',
    'click_to_confirm' => 'לחץ על הקישור הבא כדי לאשר את: חשבון האינטרנט שלך:',
    'click_on_the_link_accessory' => 'לחץ על הקישור בתחתית הדף כדי לאשר שקיבלת את האביזר.',
    'click_on_the_link_asset' => 'לחץ על הקישור שבתחתית כדי לאשר שקיבלת את הנכס.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY הנוכחי',
    'Days' => 'ימים',
    'days' => 'ימים',
    'expecting_checkin_date' => 'תאריך הצפוי:',
    'expires' => 'יפוג',
    'Expiring_Assets_Report' => 'דוח נכסים שפג תוקפם.',
    'Expiring_Licenses_Report' => 'דוח רישיונות שפג תוקפם.',
    'hello' => 'שלום',
    'hi' => 'היי',
    'i_have_read' => 'קראתי והסכמתי לתנאי השימוש וקיבלתי פריט זה.',
    'item' => 'פריט:',
    'Item_Request_Canceled' => 'פריט בקשה בוטלה',
    'Item_Requested' => 'פריט מבוקש',
    'link_to_update_password' => 'לחץ על הקישור הבא כדי לעדכן את: סיסמת האינטרנט:',
    'login_first_admin' => 'היכנס למערכת ההתקנה החדשה של Snipe-IT באמצעות פרטי הכניסה הבאים:',
    'login' => 'התחברות:',
    'Low_Inventory_Report' => 'דו"ח מלאי נמוך',
    'min_QTY' => 'מינימום QTY',
    'name' => 'שֵׁם',
    'new_item_checked' => 'פריט חדש נבדק תחת שמך, הפרטים להלן.',
    'password' => 'סיסמה:',
    'password_reset' => 'איפוס סיסמא',

    'read_the_terms' => 'אנא קרא את תנאי השימוש שלהלן.',
    'read_the_terms_and_click' => 'קרא את תנאי השימוש שלהלן ולחץ על הקישור בתחתית הדף כדי לאשר שאתה קורא את תנאי השימוש ומסכים להם, וקיבלת את הנכס.',
    'requested' => 'התקבלה:',
    'reset_link' => 'איפוס הסיסמה שלך קישור',
    'reset_password' => 'לחץ כאן כדי לאפס את הסיסמה שלך:',
    'serial' => 'מספר סידורי',
    'supplier' => 'ספק',
    'tag' => 'תָג',
    'test_email' => 'מבחן דוא"ל מאת Snipe-IT',
    'test_mail_text' => 'זהו מבחן מן Snipe- IT ניהול מערכת. אם יש לך את זה, הדואר עובד :)',
    'the_following_item' => 'הפריט הבא נבדק:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'כדי לאפס את: סיסמת האינטרנט, מלא טופס זה:',
    'type' => 'סוּג',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'משתמש',
    'username' => 'שם משתמש',
    'welcome' => 'ברוכים הבאים: שם',
    'welcome_to' => 'ברוכים הבאים ל: אינטרנט!',
    'your_credentials' => 'שלך Snipe- IT אישורים',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
